@@ -2,8 +2,10 @@
 
 from __future__ import absolute_import, print_function, unicode_literals
 
-if __name__ == '__main__':
-
+def main():
     from rpy.cli.dispatch import execute_from_command_line
+    execute_from_command_line()    
+
+if __name__ == '__main__':
+    main()
 
-    execute_from_command_line()
